@@ -1,7 +1,5 @@
 #!/usr/bin/env python3
 
-import os
-
 from .modules import fs
 
 from .modules.detector import is_int, is_num, is_float, is_str, \
@@ -19,11 +17,6 @@ from .modules.utils import throttle, timing, jprint, \
     compose, pipe, curry
 
 
-def version():
-    full_path = os.path.dirname(os.path.realpath(__file__))
-    return open(full_path + '/VERSION').read().strip()
-
-
 __all__ = [
     fs, is_int, is_num, is_float, is_str, is_bool,
     is_list, is_dict, is_valid_url,
